from typing import Generator

from chatfaq_sdk.api.knowledge_items import KnowledgeItem


class DataSourceParser:
    def __init__(self, data_source):
        self.data_source = data_source

    def parse(self) -> Generator[KnowledgeItem]:
        raise NotImplementedError()



from enum import Enum


class MessageType(Enum):
    fsm_def = "fsm_def"
    rpc_request = "rpc_request"
    rpc_result = "rpc_result"
    llm_request = "llm_request"
    llm_request_result = "llm_request_result"
    error = "error"


class RPCNodeType(Enum):
    action = "action"
    condition = "condition"


class DataSourceType(Enum):
    data_source_parsers = "data_source_parsers"



from typing import Optional
from dataclasses import dataclass


@dataclass
class KnowledgeItem:
    """
    A KnowledgeItem is a set of elements (titles, texts, urls, etc.) that are used for Retrieval Augmented Generation (RAG).
    """
    content: str
    title: Optional[str] = None
    section: Optional[str] = None
    url: Optional[str] = None
    page_number: Optional[int] = 0
    metadata: Optional[dict] = None
